/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */
package org.gvsig.publish.geoserver.conf;

import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

import junit.framework.TestCase;

import org.gvsig.publish.exceptions.PublishException;
import org.gvsig.publish.geoserver.model.Geoserver;
import org.gvsig.publish.geoserver.model.GeoserverWFSService;

public class GSConfigurationTest extends TestCase {
	private static Geoserver geoserver=null;
	private static GeoserverWFSService geoserverwfs = null;
	private static File data_dir=null;
	/**
	 * Creates the data for testing (a Geoserver instance) 
	 * 
	 * @param name
	 * @throws MalformedURLException 
	 * @throws PublishException 
	 */
	public GSConfigurationTest(String name) throws MalformedURLException{
		super(name);
		if (geoserver == null){
			initialize();
		}
	}
	private void initialize() throws MalformedURLException{
		geoserver = new Geoserver();
		data_dir = new File ("test");
		geoserver.setServerURL(new URL("http://localhost:8080/geoserver"));
		geoserver.setAdminUser("test_user");
		geoserver.setAdminPassword("test_password");
		geoserver.setConfigDirectory(data_dir);
		geoserverwfs = new GeoserverWFSService(geoserver);
	}
	/**
	 * Writes global configuration
	 * @throws IOException 
	 * @throws LayerInfoNotAvailableException 
	 */
	public void test_generateGlobalConfiguration() throws IOException {
		GSConfiguration conf = new GSConfiguration(geoserver);				
		conf.toXML();
	}
	/**
	 * Writes wfs configuration
	 * @throws IOException 
	 * @throws LayerInfoNotAvailableException 
	 */
	public void test_generateWFSConfiguration() throws IOException {
		GSConfiguration conf = new GSConfiguration(geoserver);		
		conf.getGlobals().setWFSService(geoserverwfs);
		conf.toXML();
	}
}
