/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */


package org.gvsig.publish.geoserver.conf;

//Start of user code for imports
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.gvsig.publish.PublishLogger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import com.sun.org.apache.xml.internal.serialize.OutputFormat;
import com.sun.org.apache.xml.internal.serialize.XMLSerializer;
//End of user code for imports
/**
 * 
 * @author
 */
public class GSCatalog  {

	//Attributes from associations    
	private Map datastores = null; 
	private Map namespaces = null;
	private Map formats = null;
	private Map styles = null;

	/**
	 * Default constructor
	 */
	public GSCatalog (){
		this.datastores = new HashMap();
		this.namespaces = new HashMap();
		this.formats = new HashMap();
		this.styles = new HashMap();
	}

	/**
	 * Put an element into datastores
	 * @param datastores
	 * @return true if the datastore already exists 
	 */
	public boolean addDatastore(GSDatastore item){
		if (datastores.containsKey(item.getId())){    		
			return true;
		}else{
			datastores.put(item.getId(), item);
			return false;
		}
	}
	/**
	 * Put an element into namespaces
	 * @param namespaces
	 */
	public void addNamespace(GSNamespace item){
		this.namespaces.put(item.getPrefix() ,item);
	}
	/**
	 * Put an element into styles
	 * @param namespaces
	 */
	public void addStyle(GSStyle item){
		this.styles.put(item.getId() ,item);
	}

	/**
	 * Writes the catalog.xml
	 * @param file where the catalog.xml is generated
	 * @throws IOException 
	 */

	public void toXML(File file) throws IOException{
		Document dom=null;
		//get an instance of factory
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		try {
			//get an instance of builder
			DocumentBuilder db = dbf.newDocumentBuilder();

			//create an instance of DOM
			dom = db.newDocument();

		}catch(ParserConfigurationException pce) {
			PublishLogger.getLog().error("ERROR GSCatalog: Error while trying to instantiate DocumentBuilder " + pce);
		}
		//create the root element <catalog>
		Element rootEle = dom.createElement("catalog");
		dom.appendChild(rootEle);
		//create datastore elements
		Element rootDsEle = dom.createElement("datastores");
		rootEle.appendChild(rootDsEle);		
		Iterator i = datastores.values().iterator();
		while (i.hasNext()){
			GSDatastore d = (GSDatastore) i.next();
			rootDsEle.appendChild(d.getXMLElement(dom));
		}
		//create namespace elements
		Element rootNsEle = dom.createElement("namespaces");
		rootEle.appendChild(rootNsEle);		
		i = namespaces.values().iterator();
		while (i.hasNext()){
			GSNamespace n = (GSNamespace) i.next();
			rootNsEle.appendChild(n.getXMLElement(dom));
		}
		//TODO: create style elements
		Element rootStEle = dom.createElement("styles");
		rootEle.appendChild(rootStEle);		
		i = styles.values().iterator();
		while (i.hasNext()){
			GSStyle s = (GSStyle) i.next();
			rootStEle.appendChild(s.getXMLElement(dom));
		}
		//write files
		OutputFormat format = new OutputFormat(dom);
		//omit header
		//format.setOmitXMLDeclaration(true);
		format.setIndenting(true);						
		XMLSerializer serializer = new XMLSerializer(					
				new FileOutputStream(file), format);			
		serializer.serialize(dom);			

	}


}
