/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */

package org.gvsig.publish.geoserver.conf;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.gvsig.publish.PublishLogger;
import org.gvsig.publish.geoserver.model.GeoserverFeature;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Text;

import com.sun.org.apache.xml.internal.serialize.OutputFormat;
import com.sun.org.apache.xml.internal.serialize.XMLSerializer;

/**
 * This class represents a feturetype in the Geoserver Configuration
 *  
 * @author jvhigon (josevicente.higon@iver.es)
 */
public class GSFeature  {

    //associations
    private GSStyle style;
    private GSDatastore datastore;
    private GSNamespace namespace;
    private GeoserverFeature remoteresource;
    private String id;
   
    
    //Start of user code for the default constructor
    /**
     * Default constructor
     * 
     */
    public GSFeature (GeoserverFeature remoteresource){
    	this.remoteresource = remoteresource;    	
    	this.id = remoteresource.getId();
    }
    /**
     * 
     * @return default featureType style
     */
    public GSStyle getStyle(){
    	return this.style;
    }
    /**
     * 
     * @return the featureType datastore
     */
    public GSDatastore getDatastore(){
    	return this.datastore;
    }
    /**
     * 
     * @return the featureType datastore
     */
    public GSNamespace getNamespace(){
    	return this.namespace;
    }

    /**
     * Set the value of myStyle
     * @param myStyle
     */
    public void setStyle(GSStyle myStyle){
        this.style = myStyle;
    }
    /**
     * Set the value of myDatastore
     * @param myDatastore
     */    
    public void setDatastore(GSDatastore myDatastore){
        this.datastore = myDatastore;
    }
    /**
     * Set the value of myNamespace
     * @param myNamespace
     */
    public void setNamespace(GSNamespace myNamespace){
        this.namespace = myNamespace;
    }
    
 
	/**
	 * Serialize the featureType information into a info.xml. 
	 * It creates a directory with the name "datastore_feature" and puts the info.xml inside of it. 
	 * 
	 * @param dir directory where are placed all the feature's configurations 
	 *  
	 * 
	 */
    public void toXML(File dir){    	
    	String aux = getId();
    	//String aux = getDatastore().getId() + "_" + getId();
    	//String aux = getNamespace().getPrefix() + "_" + getId();
    	//creates the directory
    	File dir_info = new File(dir.getAbsolutePath() + File.separator +  aux);
    	dir_info.mkdirs();
    	//creates the file
    	File info_xml = new File(dir_info.getAbsoluteFile() + File.separator + "info.xml");
    	Document dom=null;
    	//get an instance of factory
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		try {
		//get an instance of builder
		DocumentBuilder db = dbf.newDocumentBuilder();

		//create an instance of DOM
		dom = db.newDocument();

		}catch(ParserConfigurationException pce) {
			PublishLogger.getLog().error("ERROR " + getClass().getName() + ":Error while trying to instantiate DocumentBuilder " + pce);
		}
		//create the root element <featureType>
		Element rootEle = dom.createElement("featureType");
		rootEle.setAttribute("datastore", this.getDatastore().getId());
		dom.appendChild(rootEle);
		//name
		Element paramEle = dom.createElement("name");
		Text txt = dom.createTextNode(remoteresource.getName());
		paramEle.appendChild(txt);			
		rootEle.appendChild(paramEle);
		//title
		paramEle = dom.createElement("title");
		txt = dom.createTextNode(remoteresource.getTitle());
		paramEle.appendChild(txt);			
		rootEle.appendChild(paramEle);
		//abstract
		paramEle = dom.createElement("abstract");
		txt = dom.createTextNode(remoteresource.getAbstract());
		paramEle.appendChild(txt);			
		rootEle.appendChild(paramEle);
		//numDecimals
		paramEle = dom.createElement("numDecimals");
		txt = dom.createTextNode(new Integer(remoteresource.getNumDecimals()).toString());
		paramEle.appendChild(txt);			
		rootEle.appendChild(paramEle);		
		//keywords
		paramEle = dom.createElement("keywords");
		txt = dom.createTextNode("Not yet implemented");
		paramEle.appendChild(txt);			
		rootEle.appendChild(paramEle);		
		//SRS
		paramEle = dom.createElement("SRS");
		txt = dom.createTextNode(new Integer(remoteresource.getLayerInfo().getSRID()).toString());
		paramEle.appendChild(txt);			
		rootEle.appendChild(paramEle);
		//latLonBoundingBox
		paramEle = dom.createElement("latLonBoundingBox");
		paramEle.setAttribute("dynamic", "false");
		paramEle.setAttribute("minx", new Double(remoteresource.getLayerInfo().getDataSource().getLatLonBBox().getMinX()).toString() );
		paramEle.setAttribute("miny", new Double(remoteresource.getLayerInfo().getDataSource().getLatLonBBox().getMinY()).toString() );
		paramEle.setAttribute("maxx", new Double(remoteresource.getLayerInfo().getDataSource().getLatLonBBox().getMaxX()).toString() );
		paramEle.setAttribute("maxy", new Double(remoteresource.getLayerInfo().getDataSource().getLatLonBBox().getMaxY()).toString() );				
		rootEle.appendChild(paramEle);		
		//nativeBBox
		paramEle = dom.createElement("nativeBBox");
		paramEle.setAttribute("dynamic", "false");
		paramEle.setAttribute("minx", new Double(remoteresource.getLayerInfo().getDataSource().getNativeBBox().getMinX()).toString() );
		paramEle.setAttribute("miny", new Double(remoteresource.getLayerInfo().getDataSource().getNativeBBox().getMinY()).toString() );
		paramEle.setAttribute("maxx", new Double(remoteresource.getLayerInfo().getDataSource().getNativeBBox().getMaxX()).toString() );
		paramEle.setAttribute("maxy", new Double(remoteresource.getLayerInfo().getDataSource().getNativeBBox().getMaxY()).toString() );				
		rootEle.appendChild(paramEle);				
		//cacheinfo
		paramEle = dom.createElement("cacheinfo");
		paramEle.setAttribute("enabled", new Boolean(remoteresource.isCacheEnabled()).toString());
		paramEle.setAttribute("maxage", new Integer(remoteresource.getCacheMaxage()).toString());
		rootEle.appendChild(paramEle);
		//style default
		paramEle = dom.createElement("styles");
		paramEle.setAttribute("default", this.getStyle().getId());
		rootEle.appendChild(paramEle);		
		
		//write info.xml
		try
		{
			OutputFormat format = new OutputFormat(dom);
			format.setIndenting(true);						
			XMLSerializer serializer = new XMLSerializer(					
			new FileOutputStream(info_xml), format);
			serializer.serialize(dom);
		} catch(IOException ioe) {
		    PublishLogger.getLog().error("ERROR " + getClass().getName() + ": I can't generate the catlog.xml", ioe);
		}
		
		this.getStyle().writeSLD(dir.getParentFile());
		
    }
	/**
	 * @return the id
	 */
	public String getId() {
		return id;
	}
	/**
	 * 
	 * @param id unique identifier of the feature. It must be composed by the namespace plus "_" plus table or filename  
	 */
	public void setId(String id){
		this.id = id;
	}

}
