/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */

package org.gvsig.publish.geoserver.conf;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.gvsig.publish.PublishLogger;
import org.gvsig.publish.geoserver.model.Geoserver;
import org.gvsig.publish.geoserver.model.GeoserverWFSService;
import org.gvsig.publish.geoserver.model.GeoserverWMSService;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.Text;

import com.sun.org.apache.xml.internal.serialize.OutputFormat;
import com.sun.org.apache.xml.internal.serialize.XMLSerializer;

/**
 * This class represents the global information about Geoserver's services
 * 
 * @author jvhigon (josevicente.higon@iver.es)
 *
 */
public class GSServer  {
	private Geoserver server;

    //Attributes from associations
    private GSWFS wfs;
    private GSWMS wms;
    /**
     * Default constructor
     */
    public GSServer (Geoserver geoserver){
    	this.server = geoserver;
//        //create services
//        this.wfs = new GSWFS((GSWFSService)geoserver.getService(GSWFSService.REGISTER_TAG));
//        this.wms = new GSWMS((GSWMSService)geoserver.getService(GSWMSService.REGISTER_TAG));
    }
    /**
     * Sets the service WMS to generate the configuration  
     * @param wms
     */
    public void setWMSService(GeoserverWMSService wms){
    	this.wms = new GSWMS(wms);
    }

    /**
     * Sets the service WFS to generate the configuration  
     * @param wms
     */
    public void setWFSService(GeoserverWFSService wfs){
    	this.wfs = new GSWFS(wfs);
    }

   /**
     * Return wfs
     * @return GSWFS
     */
    public GSWFS getWFS(){
        return this.wfs;
    }
    /**
     * 
     * @return Geoserver service WMS 
     */
	public GSWMS getWMS() {		
		return this.wms;
	}
	
   	
   	/**
	 * Writes the services.xml
	 * @param file where the catalog.xml is generated
	 */
	public void toXML(File services_xml) {
		Document dom=null;
    	//get an instance of factory
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		try {
		//get an instance of builder
		DocumentBuilder db = dbf.newDocumentBuilder();

		//create an instance of DOM
		dom = db.newDocument();

		}catch(ParserConfigurationException pce) {
			PublishLogger.getLog().error("ERROR " + getClass().getName() + ":Error while trying to instantiate DocumentBuilder " + pce);
		}
		//create the root element <serverConfiguration>
		Element rootEle = dom.createElement("serverConfiguration");
		dom.appendChild(rootEle);
		
		//creates <global>
		rootEle.appendChild(getGlobalXMLElement(dom));
		
		//creates <services>
		Element srvEle = dom.createElement("services");
		rootEle.appendChild(srvEle);
		//adds wfs
		if (wfs != null){
			srvEle.appendChild(wfs.getXMLElement(dom));
		}
		//adds wms
		if(wms != null){
			srvEle.appendChild(wms.getXMLElement(dom));
		}
		//write files
		try
		{
			OutputFormat format = new OutputFormat(dom);
			format.setIndenting(true);						
			XMLSerializer serializer = new XMLSerializer(					
			new FileOutputStream(services_xml), format);
			serializer.serialize(dom);
		} catch(IOException ioe) {
		    PublishLogger.getLog().error("ERROR " + getClass().getName() + ": I can't generate the catlog.xml", ioe);
		}		
		
	}
	/**
	 * Creates the global parameters in the XML
	 * @param dom 
	 */
	private Node getGlobalXMLElement(Document dom){
		//create global elements
		Element globalEle = dom.createElement("global");
		//loginLevel
		Element paramEle = dom.createElement("loggingLevel");
		Text txt = dom.createTextNode(server.getLogginLevel());
		paramEle.appendChild(txt);			
		globalEle.appendChild(paramEle);
		//loggingToFile
		paramEle = dom.createElement("loggingToFile");
		txt = dom.createTextNode(new Boolean(server.isLoginToFile()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//JaiMemoryCapacity
		paramEle = dom.createElement("JaiMemoryCapacity");
		txt = dom.createTextNode(new Double(server.getJaiMemoryCapacity()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//JaiMemoryThreshold
		paramEle = dom.createElement("JaiMemoryThreshold");
		txt = dom.createTextNode(new Double(server.getJaiMemoryThreshold()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//JaiTileThreads
		paramEle = dom.createElement("JaiTileThreads");
		txt = dom.createTextNode(new Integer(server.getJaiTileThreads()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//JaiTilePriority
		paramEle = dom.createElement("JaiTilePriority");
		txt = dom.createTextNode(new Integer(server.getJaiTilePriority()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//JaiRecycling
		paramEle = dom.createElement("JaiRecycling");
		txt = dom.createTextNode(new Boolean(server.isJaiRecycling()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//ImageIOCache
		paramEle = dom.createElement("ImageIOCache");
		txt = dom.createTextNode(new Boolean(server.isImageIOCache()).toString());
		paramEle.appendChild(txt);
		globalEle.appendChild(paramEle);
		//JaiJPEGNative
		paramEle = dom.createElement("JaiJPEGNative");
		txt = dom.createTextNode(new Boolean(server.isJaiJPEGNative()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//JaiPNGNative
		paramEle = dom.createElement("JaiPNGNative");
		txt = dom.createTextNode(new Boolean(server.isJaiPNGNative()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//maxFeatures
		paramEle = dom.createElement("maxFeatures");
		paramEle.setAttribute("value",new Integer(server.getMaxFeatures()).toString());
		globalEle.appendChild(paramEle);
		//verbose
		paramEle = dom.createElement("verbose");
		txt = dom.createTextNode(new Boolean(server.isVerbose()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//verboseExceptions
		paramEle = dom.createElement("verboseExceptions");
		txt = dom.createTextNode(new Boolean(server.isVerboseExceptions()).toString());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//numDecimals
		paramEle = dom.createElement("numDecimals");
		paramEle.setAttribute("value",new Integer(server.getNumDecimals()).toString());		
		globalEle.appendChild(paramEle);
		//charSet
		paramEle = dom.createElement("charSet");
		paramEle.setAttribute("value",server.getCharset());
		globalEle.appendChild(paramEle);
		//adminUserName
		paramEle = dom.createElement("adminUserName");
		txt = dom.createTextNode(server.getAdminUser());
		paramEle.appendChild(txt);		
		globalEle.appendChild(paramEle);
		//adminPassword
		paramEle = dom.createElement("adminPassword");
		txt = dom.createTextNode(server.getAdminPassword());
		paramEle.appendChild(txt);						
		globalEle.appendChild(paramEle);
		
		return globalEle;
	}
	
}
