/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */

package org.gvsig.publish.geoserver.conf;

import org.gvsig.publish.ogcmetadata.IOGCServiceMetadata;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.Text;


/**
 * Responsibility: creates the XML configuration from an OGC service interface
 * @author jvhigon (josevicente.higon@iver.es)
 */
public abstract class GSService  {
	private boolean isEnabled = true;
	private IOGCServiceMetadata serviceMetadata = null;
	
	public abstract String getType();
	/**
	 * Constructor
	 * @param service
	 */
	public GSService(IOGCServiceMetadata service) {
		this.serviceMetadata = service;
	}
    //Methods 
    /**
     * @return true if the service is enabled
     */
    public boolean getEnabled(){
    	return this.isEnabled;
    }
	
    public Node getXMLElement(Document dom){
		//create root element <service> 
		Element rootEle = dom.createElement("service");
		//attributes
		rootEle.setAttribute("type", getType());
		rootEle.setAttribute("enabled", new Boolean(this.getEnabled()).toString());		
		//params
		//name
		Element paramEle = dom.createElement("name");
		Text txt = dom.createTextNode(serviceMetadata.getName());
		paramEle.appendChild(txt);
		rootEle.appendChild(paramEle);
		//title
		paramEle = dom.createElement("title");
		txt = dom.createTextNode(serviceMetadata.getTitle());
		paramEle.appendChild(txt);
		rootEle.appendChild(paramEle);
		//abstract
		paramEle = dom.createElement("abstract");
		txt = dom.createTextNode(serviceMetadata.getAbstract());
		paramEle.appendChild(txt);
		rootEle.appendChild(paramEle);
		//keywords
		paramEle = dom.createElement("keywords");
		rootEle.appendChild(paramEle);
		//TODO: I must put keywords in the common metadata
		Element keyEle = dom.createElement("keyword");
		Text tx = dom.createTextNode("Not implemented yet");
		keyEle.appendChild(tx);
		paramEle.appendChild(keyEle);
		
//		Iterator i = this.keywords.iterator();
//		while (i.hasNext()){
//			String keyword = (String)i.next();
//			Element keyEle = dom.createElement("keyword");
//			Text tx = dom.createTextNode(keyword);
//			keyEle.appendChild(tx);
//			paramEle.appendChild(keyEle);
//		}
		
		//onlineResource
		paramEle = dom.createElement("onlineResource");
		txt = dom.createTextNode(serviceMetadata.getOnlineResource().toString());
		paramEle.appendChild(txt);
		rootEle.appendChild(paramEle);
		//TODO:metadatalink
		
		//TODO:fees
		//TODO:accessConstraints
		//TODO:srsXmlStyle
		//TODO:maintainer
		
		return rootEle;
    }
	
}
