/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */

package org.gvsig.publish.geoserver.conf;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.io.Writer;

import org.gvsig.publish.PublishLogger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import com.iver.utiles.FileUtils;


/**
 * 
 * @author
 */
public class GSStyle  {
	private String id;
	private File sld;
	private String sld_string;
	

    /**
     * Sets the style identifier. It the style exists in the catalog
     * it will be override
     * @param id 
     */
    public void setId(String id) {
    	this.id = id;
    }
    /**
     * 
     * @return unique identifier to identify the style
     */
    public String getId(){
    	return this.id;
    }
	
    /**
     * 
     * @param sld string which will be copied into styles directory as a file
     *  
     */
    public void setSLDString(String sld) {
    	this.sld_string = sld;    		
    }
    /**
     * 
     * @return name of the filename (sld) located in the styles directory 
     */
    public String getFilename(){
    	return this.id + ".sld";
    }
    
    /**
     * Copy sld file into styles directory in the geoserver_data_dir
     * If the directory not exists it will be created
     *  
     * @param dir geoserver_data_dir
     */
    public void copySLD(File dir){
    	File styles_dir = new File(dir.getAbsolutePath() + File.separator + "styles");
    	//creates the directory if not exists
    	if (!styles_dir.exists())
    		styles_dir.mkdirs();
    	//create sld
    	File dst = new File(styles_dir.getAbsolutePath() + File.separator + getId() + ".sld");
    	//copy 
    	try {
    		FileUtils.copy(this.sld, dst);
    	} catch (IOException e) {
    		PublishLogger.getLog().error("ERROR " + getClass().getName() + ": can't write sld ", e);
    	}

    }
    /**
     * Writes into a file the sld string
     * 
     * @param dir geoserver data configuration dir
     */
    public void writeSLD(File dir){
    	File styles_dir = new File(dir.getAbsolutePath() + File.separator + "styles");
    	//creates the directory if not exists
    	if (!styles_dir.exists())
    		styles_dir.mkdirs();
    	//create sld
    	File dst = new File(styles_dir.getAbsolutePath() + File.separator + getId() + ".sld");
    	//copy
    	Writer output = null;
    	FileOutputStream fileoutput=null;
    	try {
    		fileoutput = new FileOutputStream(dst);
    	} catch (FileNotFoundException e) {
    		PublishLogger.getLog().error("ERROR " + getClass().getName() + ": file not found" ,e);
    	}
    	try {
    		output = new OutputStreamWriter(fileoutput, "UTF-8");
    	} catch (UnsupportedEncodingException e) {
    		PublishLogger.getLog().error("ERROR " + getClass().getName() + ": file not found" ,e);		
    	}
    	try {
			output.write(this.sld_string);
		} catch (IOException e) {
			PublishLogger.getLog().error("ERROR " + getClass().getName() + ": io exception writting file" ,e);		
		}
		try {
			output.flush();
			output.close();
		} catch (IOException e) {
			PublishLogger.getLog().error("ERROR " + getClass().getName() + ": io exception closing file" ,e);
		}
    }
    
	public Node getXMLElement(Document dom) {
		//set root element
		Element rootEle = dom.createElement("style");
		//set attributes
		rootEle.setAttribute("id", this.getId());
		rootEle.setAttribute("filename",this.getFilename());		
		return rootEle;
	}
	
}
