/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */
package org.gvsig.publish.geoserver.gui;

import java.awt.event.ActionListener;
import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.EventListener;

import javax.swing.JOptionPane;
import javax.swing.JPanel;

import org.gvsig.publish.PublishExtension;
import org.gvsig.publish.PublishLogger;
import org.gvsig.publish.geoserver.model.Geoserver;
import org.gvsig.publish.gui.publish.IPublishPluginPanel;

import com.iver.andami.PluginServices;

public class GeoserverBasicPanel extends JPanel implements IPublishPluginPanel {
	/**
	 * 
	 */
	private static final long serialVersionUID = 5118882315404005726L;
	//Association
	private Geoserver model=null;
	/**
	 * Default constructor
	 */
	public GeoserverBasicPanel() {
		super();
		initComponents();
		initIcons();
		initLabels();
	}
	/**
	 * initialize icons
	 */
	private void initIcons(){
		//open dir
		try {
			dirButton.setIcon(new javax.swing.ImageIcon(PublishExtension.class.getClassLoader().getResource("images/publish-fileopen.gif")));			
		}catch( java.lang.NullPointerException e){
			PublishLogger.getLog().error("ERROR " + getClass().getName() + ":Error loading icons", e);
		}
		//geoserver logo
		try {
			icon.setIcon(new javax.swing.ImageIcon(getClass().getClassLoader().getResource("images/publish-geoserver.png")));			
		}catch( java.lang.NullPointerException e){
			PublishLogger.getLog().error("ERROR " + getClass().getName() + ":Error loading icons", e);
		}		
	}

	/**
	 * Initializes labels for multi-language
	 */
	private void initLabels() {
		 userLabel.setText(PluginServices.getText(this,"publishgs_user"));
		 passLabel.setText(PluginServices.getText(this, "publishgs_pass"));
		 dirLabel.setText(PluginServices.getText(this, "publishgs_dir"));
		 urlLabel.setText(PluginServices.getText(this, "publishgs_url"));		 
	}
	private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        userText = new javax.swing.JTextField();
        userLabel = new javax.swing.JLabel();
        passText = new javax.swing.JPasswordField();
        passLabel = new javax.swing.JLabel();
        dirText = new javax.swing.JTextField();
        dirLabel = new javax.swing.JLabel();
        dirButton = new org.gvsig.gui.beans.swing.JButton();
        urlText = new javax.swing.JTextField();
        urlLabel = new javax.swing.JLabel();
        jSeparator1 = new javax.swing.JSeparator();
        icon = new javax.swing.JLabel();

        setLayout(new java.awt.GridBagLayout());

        userText.setText("user");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 5);
        add(userText, gridBagConstraints);

        userLabel.setText("user");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(2, 5, 2, 2);
        add(userLabel, gridBagConstraints);

        passText.setText("jPasswordField1");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 5);
        add(passText, gridBagConstraints);

        passLabel.setText("pass");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(2, 5, 2, 2);
        add(passLabel, gridBagConstraints);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        add(dirText, gridBagConstraints);

        dirLabel.setText("dir");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(2, 5, 2, 2);
        add(dirLabel, gridBagConstraints);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 4;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.insets = new java.awt.Insets(1, 2, 2, 5);
        add(dirButton, gridBagConstraints);

        urlText.setEditable(false);
        urlText.setText("http://");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 5);
        add(urlText, gridBagConstraints);

        urlLabel.setText("url");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(2, 5, 2, 2);
        add(urlLabel, gridBagConstraints);

        jSeparator1.setName(""); // NOI18N
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(10, 10, 10, 10);
        add(jSeparator1, gridBagConstraints);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        add(icon, gridBagConstraints);
    }// </editor-fold>
    
    
    // Variables declaration - do not modify
    private org.gvsig.gui.beans.swing.JButton dirButton;
    private javax.swing.JLabel dirLabel;
    private javax.swing.JTextField dirText;
    private javax.swing.JLabel icon;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JLabel passLabel;
    private javax.swing.JPasswordField passText;
    private javax.swing.JLabel urlLabel;
    private javax.swing.JTextField urlText;
    private javax.swing.JLabel userLabel;
    private javax.swing.JTextField userText;
    // End of variables declaration
    	 
    /**
     * update the model with the GUI
     */
	public Object getModel() {
		try {
			model.setServerURL(new URL(urlText.getText()));
		} catch (MalformedURLException e) {
			JOptionPane.showMessageDialog(this,
					PluginServices.getText(this,"publishgs_malformed_url"),
					PluginServices.getText(this,"publishgs_malformed_url"),
					JOptionPane.ERROR_MESSAGE);
		}
		model.setAdminUser(userText.getText());
		model.setAdminPassword(new String(passText.getPassword()));
		model.setConfigDirectory(new File(dirText.getText()));
		return model;
	}
	/**
	 * sets the listener for the filechooser
	 */
	public void setListener(EventListener listener) {
		dirButton.addActionListener((ActionListener)listener);
		dirButton.setActionCommand(GeoserverController.SELECT_DIR_EVENT);
	}
	/**
	 * Fill the GUI with the model
	 */
	public void setModel(Object entityModel) {
		// cast to Geoserver
		model = (Geoserver)entityModel;
		urlText.setText(model.getServerURL().toString());
		userText.setText(model.getAdminUser());
		passText.setText(model.getAdminPassword());
		if (model.getConfigDirectory()!=null){
			dirText.setText(model.getConfigDirectory().getAbsolutePath());
		}
	}

}
