/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */
package org.gvsig.publish.geoserver.gui;

import java.awt.event.ActionEvent;
import java.io.File;

import javax.swing.JFileChooser;

import org.gvsig.publish.geoserver.model.Geoserver;
import org.gvsig.publish.gui.ogcMetadata.OGCCommonMetadataPanel;
import org.gvsig.publish.gui.ogcMetadata.OGCWFSPanel;
import org.gvsig.publish.gui.publish.IPublishPluginPanel;
import org.gvsig.publish.gui.wizard.PublishWizardController;
import org.gvsig.publish.serversmodel.RemoteResource;
import org.gvsig.publish.serversmodel.Server;
import org.gvsig.publish.serversmodel.Service;
/**
 * Geoserver GUI controller.
 * 
 * @author jvhigon
 *
 */
public class GeoserverController extends PublishWizardController{
	//EVENTS
	public final static String SELECT_DIR_EVENT="select_dir_event";
	
	//Associations
	private IPublishPluginPanel serverBasicPanel = null;
	private IPublishPluginPanel serverAdvancedPanel = null;
	private IPublishPluginPanel serviceBasicPanel = null;
	private IPublishPluginPanel serviceAdvancedPanel = null;
	private IPublishPluginPanel resourceBasicPanel = null;
	private IPublishPluginPanel resourceAdvancedPanel = null;
	private GSFileChooser dirChooser = null;
	private Geoserver active_server=null;
	/**
	 * Default constructor
	 */
	public GeoserverController() {
		super();
		serverBasicPanel = new GeoserverBasicPanel();
		serverAdvancedPanel = new GeoserverAdvancedPanel();
		serviceBasicPanel = new OGCWFSPanel();
		serviceAdvancedPanel = new GSWFSAdvancedPanel();
		resourceBasicPanel = new OGCCommonMetadataPanel(); 
		resourceAdvancedPanel = new GSFeatureResourceAdvancedPanel();
		dirChooser = new GSFileChooser();
		//set listener
		serverBasicPanel.setListener(this);
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.gui.wizard.PublishWizardController#getRemoteResourceAdvancedPanel(org.gvsig.publish.serversmodel.RemoteResource)
	 */
	public IPublishPluginPanel getRemoteResourceAdvancedPanel(
			RemoteResource remoteResource) {
		resourceAdvancedPanel.setModel(remoteResource);
		return resourceAdvancedPanel;
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.gui.wizard.PublishWizardController#getRemoteResourcePanel(org.gvsig.publish.serversmodel.RemoteResource)
	 */
	public IPublishPluginPanel getRemoteResourcePanel(
			RemoteResource remoteResource) {
		resourceBasicPanel.setModel(remoteResource);
		return resourceBasicPanel;
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.gui.wizard.PublishWizardController#getServerAdvancedPanel(org.gvsig.publish.serversmodel.Server)
	 */
	public IPublishPluginPanel getServerAdvancedPanel(Server server) {
		serverAdvancedPanel.setModel(server);
		return serverAdvancedPanel;
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.gui.wizard.PublishWizardController#getServerPanel(org.gvsig.publish.serversmodel.Server)
	 */
	public IPublishPluginPanel getServerPanel(Server server) {
		active_server = (Geoserver)server;
		serverBasicPanel.setModel(server);
		return serverBasicPanel;
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.gui.wizard.PublishWizardController#getServiceAdvancedPanel(org.gvsig.publish.serversmodel.Service)
	 */
	public IPublishPluginPanel getServiceAdvancedPanel(Service service) {
		serviceAdvancedPanel.setModel(service);
		return serviceAdvancedPanel;
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.gui.wizard.PublishWizardController#getServicePanel(org.gvsig.publish.serversmodel.Service)
	 */
	public IPublishPluginPanel getServicePanel(Service service) {
		serviceBasicPanel.setModel(service);
		return serviceBasicPanel;
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.gui.wizard.PublishWizardController#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {	
		super.actionPerformed(e);
		if (e.getActionCommand().equals(SELECT_DIR_EVENT)){
			//first, update model 
			serverBasicPanel.getModel();
			int returnVal = dirChooser.showSaveDialog((GeoserverBasicPanel)serverBasicPanel);
			if (returnVal == JFileChooser.APPROVE_OPTION){
				File dirconf = dirChooser.getSelectedFile();
				active_server.setConfigDirectory(dirconf);
				serverBasicPanel.setModel(active_server);
			}
		}
	}


}
