/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */
package org.gvsig.publish.geoserver.model;

import java.io.File;
import java.io.IOException;

import org.gvsig.publish.PublishLogger;
import org.gvsig.publish.exceptions.PublishException;
import org.gvsig.publish.geoserver.conf.GSConfiguration;
import org.gvsig.publish.serversmodel.Server;

import com.iver.andami.PluginServices;
import com.iver.utiles.XMLEntity;
/**
 * This class represents the server Geoserver.
 *
 * @author jvhigon
 *
 */
public class Geoserver extends Server {
	/*
	 * Constant to identify the server
	 */
	public static final String REGISTER_TAG = "Geoserver";

	//constants
	public static final String LOG_SEVERE="SEVERE";
	public static final String LOG_WARNING="WARNING";
	public static final String LOG_INFO="INFO";
	public static final String LOG_CONFIG="CONFIG";
	public static final String LOG_FINNER="FINNER";
	public static final String LOG_FINNEST="FINNEST";

	//Attributes
	private boolean loginToFile=false;
	private double jaiMemoryCapacity=0.5;
	private double jaiMemoryThreshold=0.75;
	private int jaiTileThreads=7;
	private int jaiTilePriority=5;
	private boolean jaiRecycling=true;
	private boolean ImageIOCache=false;
	private boolean JaiJPEGNative=true;
	private boolean jaiPNGNative=true;
	private boolean verbose=false;
	private boolean verboseExceptions=false;
	private int numDecimals=8;
	private String logginLevel=LOG_INFO;
	private int maxFeatures=2000;
	private String charset="UTF-8";
	private String adminUser="admin";
	private String adminPassword="geoserver";

	private File configDirectory;
	private GSConfiguration configuration=null;

	/**
	 * Constructor.
	 *  
	 */
	public Geoserver() {
		super();				
	}

	/**
	 * TODO: 
	 */
	public void postInitialize() {
		// TODO Auto-generated method stub

	}
	/*
	 * (non-Javadoc)
	 * @see com.iver.utiles.IPersistance#getClassName()
	 */
	public String getClassName() {		
		return "Geoserver";
	}

	public File getConfigDirectory() {
		return configDirectory;
	}

	public void setConfigDirectory(File configDirectory) {
		this.configDirectory = configDirectory;
	}

	/**
	 * 
	 * @see org.gvsig.publish.serversmodel.Server#publish()
	 */
	public String publish() throws PublishException {		
		//generate server configuration 
		checkParameters();			
		configuration  = new GSConfiguration(this);
		//generate services configuration
		super.publish();
		//write configuration
		try {
			configuration.toXML();
		} catch (IOException e) {
			throw new PublishException("publihsgs_permission_denied");
		}
		return "publishgs_publish_message";
	}
	/**
	 * check a minimum of parameters for publishing 
	 * 
	 * @throws PublishException
	 */
	private void checkParameters()throws PublishException{
		//check config directory
		//TODO: this code never is executed
		if (configDirectory == null){
			throw new PublishException("config_dir_not_defined");
		}
		//check user
		if (getAdminUser() == null){
			throw new PublishException("user_not_defined");
		}
		//check password
		if (getAdminPassword() == null){
			throw new PublishException("password_not_defined");
		}
		//check if there is anything to publish		
		if (getPublication().getProjectInfo() == null){
			throw new PublishException(PluginServices.getText(this,"nothing_to_publish"));
		}
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Server#getId()
	 */
	public String getId() {		
		return "geoserver";
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Server#getRegisterTag()
	 */
	public String getRegisterTag() {		
		return REGISTER_TAG;
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.IPublishPersistence#getVersion()
	 */
	public int getVersion() {
		return 1;
	}
	/* (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Server#getXMLEntity()
	 */

	public XMLEntity getXMLEntity() {		
		XMLEntity xml=super.getXMLEntity();
		//put version and name 
		xml.setName(getClassName());
		xml.putProperty("version", getVersion());
		//put properties		
		xml.putProperty("configdir", getConfigDirectory());
		//put config properties
		xml.putProperty("max_features", getMaxFeatures());
		xml.putProperty("login_level", getLogginLevel());
		return xml;
	}
	/* (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Server#setXMLEntity(com.iver.utiles.XMLEntity)
	 */

	public void setXMLEntity(XMLEntity xml) {
		//check version
		int version = xml.getIntProperty("version");
		if (version != getVersion()){
			PublishLogger.getLog().error("ERROR: " + getClassName() + ": the version doesn't match!");
			return;
		}	
		super.setXMLEntity(xml);
		//set properties
		String file = xml.getStringProperty("configdir");
		if (file !=null)
			setConfigDirectory(new File(file));
		//set config properties
		setMaxFeatures(xml.getIntProperty("max_features"));
		setLogginLevel(xml.getStringProperty("login_level"));
	}

	/**
	 * Return loginToFile
	 * @return boolean
	 */	
	public boolean isLoginToFile() {
		return loginToFile;
	}

	/**
	 * @param loginToFile the loginToFile to set
	 */
	public void setLoginToFile(boolean loginToFile) {
		this.loginToFile = loginToFile;
	}

	/**
	 * @return the jaiMemoryCapacity
	 */
	public double getJaiMemoryCapacity() {
		return jaiMemoryCapacity;
	}

	/**
	 * @param jaiMemoryCapacity the jaiMemoryCapacity to set
	 */
	public void setJaiMemoryCapacity(double jaiMemoryCapacity) {
		this.jaiMemoryCapacity = jaiMemoryCapacity;
	}

	/**
	 * @return the jaiMemoryThreshold
	 */
	public double getJaiMemoryThreshold() {
		return jaiMemoryThreshold;
	}

	/**
	 * @param jaiMemoryThreshold the jaiMemoryThreshold to set
	 */
	public void setJaiMemoryThreshold(double jaiMemoryThreshold) {
		this.jaiMemoryThreshold = jaiMemoryThreshold;
	}

	/**
	 * @return the jaiTileThreads
	 */
	public int getJaiTileThreads() {
		return jaiTileThreads;
	}

	/**
	 * @param jaiTileThreads the jaiTileThreads to set
	 */
	public void setJaiTileThreads(int jaiTileThreads) {
		this.jaiTileThreads = jaiTileThreads;
	}

	/**
	 * @return the jaiTilePriority
	 */
	public int getJaiTilePriority() {
		return jaiTilePriority;
	}

	/**
	 * @param jaiTilePriority the jaiTilePriority to set
	 */
	public void setJaiTilePriority(int jaiTilePriority) {
		this.jaiTilePriority = jaiTilePriority;
	}

	/**
	 * @return the jaiRecycling
	 */
	public boolean isJaiRecycling() {
		return jaiRecycling;
	}

	/**
	 * @param jaiRecycling the jaiRecycling to set
	 */
	public void setJaiRecycling(boolean jaiRecycling) {
		this.jaiRecycling = jaiRecycling;
	}

	/**
	 * @return the imageIOCache
	 */
	public boolean isImageIOCache() {
		return ImageIOCache;
	}

	/**
	 * @param imageIOCache the imageIOCache to set
	 */
	public void setImageIOCache(boolean imageIOCache) {
		ImageIOCache = imageIOCache;
	}

	/**
	 * @return the jaiJPEGNative
	 */
	public boolean isJaiJPEGNative() {
		return JaiJPEGNative;
	}

	/**
	 * @param jaiJPEGNative the jaiJPEGNative to set
	 */
	public void setJaiJPEGNative(boolean jaiJPEGNative) {
		JaiJPEGNative = jaiJPEGNative;
	}

	/**
	 * @return the jaiPNGNative
	 */
	public boolean isJaiPNGNative() {
		return jaiPNGNative;
	}

	/**
	 * @param jaiPNGNative the jaiPNGNative to set
	 */
	public void setJaiPNGNative(boolean jaiPNGNative) {
		this.jaiPNGNative = jaiPNGNative;
	}

	/**
	 * @return the verbose
	 */
	public boolean isVerbose() {
		return verbose;
	}

	/**
	 * Whether newlines and indents should be returned in
	 * XML responses.  Default is false
	 * @param verbose 
	 */
	public void setVerbose(boolean verbose) {
		this.verbose = verbose;
	}

	/**
	 * @return the verboseExceptions
	 */
	public boolean isVerboseExceptions() {
		return verboseExceptions;
	}

	/**
	 * @param verboseExceptions the verboseExceptions to set
	 */
	public void setVerboseExceptions(boolean verboseExceptions) {
		this.verboseExceptions = verboseExceptions;
	}

	/**
	 * @return the numDecimals
	 */
	public int getNumDecimals() {
		return numDecimals;
	}


	/**
	 * Sets the max number of decimal places past the zero returned in
	 * a GetFeature response.  Default is 4
	 * @param mynumDecimals 
	 */
	public void setNumDecimals(int numDecimals) {
		this.numDecimals = numDecimals;
	}

	/**
	 * Return LoginLevel 
	 * @return string SEVERE, WARNING, INFO, CONFIG, FINER, FINEST
	 */
	public String getLogginLevel() {
		return logginLevel;
	}

	/**
	 *  Defines the logging level.  Common options are SEVERE,
	 * WARNING, INFO, CONFIG, FINER, FINEST, in order of
	 *  Increasing statements logged.
	 * @see {@link Geoserver#LOG_CONFIG} , {@link Geoserver#LOG_INFO} , ...
	 * @param level SEVERE, WARNING, INFO, CONFIG, FINER, FINEST
	 *  
	 */
	public void setLogginLevel(String logginLevel) {
		this.logginLevel = logginLevel;
	}

	/**
	 * @return the maxFeatures
	 */
	public int getMaxFeatures() {
		return maxFeatures;
	}

	/**
	 * Sets the max number of features the WFS service can return 
	 * @param maxFeatures the maxFeatures to set
	 */
	public void setMaxFeatures(int maxFeatures) {
		this.maxFeatures = maxFeatures;
	}

	/**
	 * This could use some more testing
	 * from international users, but what it does is sets the encoding
	 * globally for all postgis database connections (the charset tag
	 * in FeatureTypeConfig), as well as specifying the encoding in the return
	 * config.xml header and mime type.  The default is UTF-8.  Also be warned
	 * that GeoServer does not check if the CharSet is valid before
	 * attempting to use it, so it will fail miserably if a bad charset
	 * is used.
	 * @return charset
	 */

	public String getCharset() {
		return charset;
	}


	/**
	 * @param charset the charset to set
	 */
	public void setCharset(String charset) {
		this.charset = charset;
	}

	/**
	 * @return the administrator user
	 */
	public String getAdminUser() {
		return adminUser;
	}

	/**
	 *  Defines the user name of the administrator for log in
	 * to the web based administration tool.
	 * @param user 
	 */

	public void setAdminUser(String user) {
		this.adminUser = user;
	}

	/**
	 * @return the password
	 */
	public String getAdminPassword() {
		return adminPassword;
	}

	/**
	 * @param password the password to set
	 */
	public void setAdminPassword(String password) {
		this.adminPassword = password;
	}

	/**
	 * @return the configuration
	 */
	public GSConfiguration getConfiguration() {
		return configuration;
	}

	/**
	 * @param configuration the configuration to set
	 */
	public void setConfiguration(GSConfiguration configuration) {
		this.configuration = configuration;
	}

}
