/* gvSIG. Sistema de Información Geográfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004-2006 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *   Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibañez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *   +34 963862235
 *   gvsig@gva.es
 *   www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */
package org.gvsig.publish.geoserver.model;

import java.net.MalformedURLException;
import java.net.URL;

import org.gvsig.publish.PublishLogger;
import org.gvsig.publish.exceptions.PublishException;
import org.gvsig.publish.infoproject.FilterProjectInfo;
import org.gvsig.publish.ogcmetadata.IOGCServiceMetadata;
import org.gvsig.publish.ogcmetadata.OGCServiceMetadata;
import org.gvsig.publish.serversmodel.Service;
/**
 * This class represents the Geoserver WMS Service.
 * 
 * Responsibilities:
 *  Persist its attributes.
 *  Generate the configuration related to the Geoserver WMS service 
 * 
 * @author jvhigon (josevicente.higon@iver.es)
 *
 */
public class GeoserverWMSService extends Service implements IOGCServiceMetadata{
	public static final String REGISTER_TAG="WMS 1.1.1";
	//common attributes
	private OGCServiceMetadata ogcMetadata= null;
	private FilterProjectInfo filter = null;
	//Geoserver attributes
	private boolean enabled=false;
	
	/**
	 * Constructor
	 * @param server
	 */
	public GeoserverWMSService(Geoserver server) {
		super(server);
		ogcMetadata = new OGCServiceMetadata();
		initialize();
	}
	/**
	 * initialize default values
	 */
	private void initialize() {
		//setting url
		URL url = getServer().getServerURL();
		URL aux=null;	
		try {
			aux = new URL(url.toString() + "/wms");
		} catch (MalformedURLException e) {
			PublishLogger.getLog().error("what are you doing my friend!", e);
		}catch (NullPointerException e){
			PublishLogger.getLog().warn("WARNING " + getClassName() +  ":The server don't have URL",e );
		}
		//setting name, title and abstract			
		setName("OGC:WMS");
		setTitle("Geoserver WMS 1.1.1 service");
		setAbstract("Generated by gvSIG");		
		setOnlineResource(aux);
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Service#getFilter()
	 */
	public FilterProjectInfo getFilter() {
		// TODO Auto-generated method stub
		return null;
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Service#getId()
	 */
	public String getId() {
		// TODO Auto-generated method stub
		return null;
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Service#getRegisterTag()
	 */
	public String getRegisterTag() {
		return REGISTER_TAG;
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.IPublishPersistence#getVersion()
	 */
	public int getVersion() {
		return 1;
	}
	/*
	 * (non-Javadoc)
	 * @see com.iver.utiles.IPersistance#getClassName()
	 */
	public String getClassName() {
		
		return "GeoserverWMSService";
	}

	/* (non-Javadoc)
	 * @see org.gvsig.publish.serversmodel.Service#publish()
	 */
	
	public void publish() throws PublishException {
		Geoserver server = (Geoserver)getServer();	
		//generate services configuration
		server.getConfiguration().getGlobals().setWMSService(this);		
		//generate remote resources configuration
		super.publish();
	}
	/**
	 * @return the enabled
	 */
	public boolean isEnabled() {
		return enabled;
	}
	/**
	 * @param enabled the enabled to set
	 */
	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCServiceMetadata#getOnlineResource()
	 */
	public URL getOnlineResource() {
		
		return ogcMetadata.getOnlineResource();
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCServiceMetadata#setOnlineResource(java.net.URL)
	 */
	public void setOnlineResource(URL url) {
		ogcMetadata.setOnlineResource(url);
		
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCCommonMetadata#getAbstract()
	 */
	public String getAbstract() {
		
		return ogcMetadata.getAbstract();
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCCommonMetadata#getName()
	 */
	public String getName() {
		return ogcMetadata.getName();
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCCommonMetadata#getTitle()
	 */
	public String getTitle() {
		
		return ogcMetadata.getTitle();
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCCommonMetadata#setAbstract(java.lang.String)
	 */
	public void setAbstract(String description) {
		ogcMetadata.setAbstract(description);
		
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCCommonMetadata#setName(java.lang.String)
	 */
	public void setName(String name) {
		ogcMetadata.setName(name);
		
	}
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.publish.ogcmetadata.IOGCCommonMetadata#setTitle(java.lang.String)
	 */
	public void setTitle(String title) {
		ogcMetadata.setTitle(title);
		
	}

}
